package dk.vajhoej.vms.indexf;

import java.io.FileInputStream;
import java.io.IOException;

import dk.vajhoej.record.LengthProvider2;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.StructReader;
import dk.vajhoej.record.StructReaderStream;

/**
 * Class IndexFFile represents a readable INDEXF.SYS.
 */
public class IndexFFile {
	private LengthProvider2 lenpvd;
	private StructReaderStream srs;
	/**
	 * Construct instance.
	 * @param fnm INDEXF.SYS to read
	 * @throws IOException if error opening or reading file
	 * @throws RecordException if error parsing file
	 */
	public IndexFFile(String fnm) throws IOException, RecordException {
		lenpvd = new IndexFProvider();
		FileInputStream is = new FileInputStream(fnm);
		byte[] blk = new byte[512];
		is.read(blk); // skip boot block
		is.read(blk); // read home block to get start of files
		StructReader sr = new StructReader(blk);
		PartialHomeBlock home = sr.read(PartialHomeBlock.class);
		int start_files = 4 * home.getCluster() + home.getIbmapsize();
		for(int i = 2; i < start_files; i++) is.read(blk); // skip until start of files
		srs = new StructReaderStream(is, 512, 1000);
	}
	/**
	 * More records.
	 * @return true if more records, false if no more records
	 * @throws IOException if error accessing accounting file
	 */
	public boolean more() throws IOException {
		return srs.more();
	}
	/**
	 * Read INDEXF.SYS record sequentially.
	 * @return INDEXF.SYS record read
	 * @throws RecordException if error parsing record
	 * @throws IOException if error reading record
	 */
	public IndexFRecord read() throws RecordException, IOException {
		return srs.read(IndexFRecord.class, lenpvd);
	}
	/**
	 * Close INDEXF.SYS.
	 * @throws IOException if error closing INDEXF.SYS
	 */
	public void close() throws IOException {
		srs.close();
	}
}
