package dk.vajhoej.vms.indexf;

import java.util.Date;

import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class IndexFRecord2 represents an INDEXF.SYS record for an ODS-2 file.
 */
@Struct
public class IndexFRecord2 extends IndexFRecord {
	// **** start Ident Area
	@StructField(n=22,type=FieldType.FIXSTR,length=20)
	private String fileName;
	@StructField(n=23,type=FieldType.INT2)
	private int revison;
	@StructField(n=24,type=FieldType.VMSTIME)
	private Date creDate;
	@StructField(n=25,type=FieldType.VMSTIME)
	private Date revDate;
	@StructField(n=26,type=FieldType.VMSTIME)
	private Date expDate;
	@StructField(n=27,type=FieldType.VMSTIME)
	private Date bakDate;
	@StructField(n=28,type=FieldType.FIXSTR,length=66)
	private String fileNameExt;
	// **** end Ident Area
	@ArrayField(elements=-1) // elements dynamically calculated
	@StructField(n=29,type=FieldType.INT1)
	private byte[] space2 = new byte[512];
	@StructField(n=30,type=FieldType.INT2)
	private short checksum;
	/**
	 * Get file name.
	 * @return file name
	 */
	public String getFileName() {
		return fileName.trim() + fileNameExt.trim();
	}
	/**
	 * Get revision.
	 * @return revision
	 */
	public int getRevison() {
		return revison;
	}
	/**
	 * Get creation date.
	 * @return creation date 
	 */
	public Date getCreDate() {
		return creDate;
	}
	/**
	 * Get revision date.
	 * @return revision date
	 */
	public Date getRevDate() {
		return revDate;
	}
	/**
	 * Get expiration date.
	 * @return expiration date.
	 */
	public Date getExpDate() {
		return expDate;
	}
	/**
	 * Get backup date.
	 * @return backup date
	 */
	public Date getBakDate() {
		return bakDate;
	}
	@Override
	public short getChecksum() {
		return checksum;
	}
	@Override
	public int getSpace2Index() {
		return 29;
	}
	@Override
	public int getIdentAreaSize() {
		return 120;
	}
}
