package dk.vajhoej.vms.indexf;

import java.util.Date;

import dk.vajhoej.record.ArrayField;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class IndexFRecord5 represents an INDEXF.SYS record for an ODS-5 file.
 */
@Struct
public class IndexFRecord5 extends IndexFRecord {
	// **** start Ident Area
	@StructField(n=22,type=FieldType.INT1)
	private int control;
	@StructField(n=23,type=FieldType.INT1)
	private int nameLen;
	@StructField(n=24,type=FieldType.INT2)
	private int revison;
	@StructField(n=25,type=FieldType.VMSTIME)
	private Date creDate;
	@StructField(n=26,type=FieldType.VMSTIME)
	private Date revDate;
	@StructField(n=27,type=FieldType.VMSTIME)
	private Date expDate;
	@StructField(n=28,type=FieldType.VMSTIME)
	private Date bakDate;
	@StructField(n=29,type=FieldType.VMSTIME)
	private Date accDate;
	@StructField(n=30,type=FieldType.VMSTIME)
	private Date attDate;
	@ArrayField(elements=8)
	@StructField(n=31,type=FieldType.INT1)
	private int recAttrExt;
	@ArrayField(elements=2)
	@StructField(n=32,type=FieldType.INT8)
	private long[] hint = new long[2];
	@StructField(n=33,type=FieldType.FIXSTR,length=44)
	private String fileName;
	@StructField(n=34,type=FieldType.FIXSTR,length=204)
	private String fileNameExt;
	// **** end Ident Area
	@ArrayField(elements=-1) // elements dynamically calculated
	@StructField(n=35,type=FieldType.INT1)
	private byte[] space2 = new byte[512];
	@StructField(n=36,type=FieldType.INT2)
	private short checksum;
	/**
	 * Get control value.
	 * @return control value
	 */
	public int getControl() {
		return control;
	}
	/**
	 * Get revision.
	 * @return revision
	 */
	public int getRevison() {
		return revison;
	}
	/**
	 * Get creation date.
	 * @return creation date
	 */
	public Date getCreDate() {
		return creDate;
	}
	/**
	 * Get revision date.
	 * @return revision date
	 */
	public Date getRevDate() {
		return revDate;
	}
	/**
	 * Get expiration date.
	 * @return expiration date
	 */
	public Date getExpDate() {
		return expDate;
	}
	/**
	 * Get backup date.
	 * @return backup date
	 */
	public Date getBakDate() {
		return bakDate;
	}
	/**
	 * Get access date.
	 * @return access date
	 */
	public Date getAccDate() {
		return accDate;
	}
	/**
	 * Get attribute date.
	 * @return attribute date
	 */
	public Date getAttDate() {
		return attDate;
	}
	/**
	 * Get extended record attributes.
	 * @return extended record attributes
	 */
	public int getRecAttrExt() {
		return recAttrExt;
	}
	/**
	 * Get hints.
	 * @return hints
	 */
	public long[] getHint() {
		return hint;
	}
	/**
	 * Get file name.
	 * @return file name
	 */
	public String getFileName() {
		return (fileName + fileNameExt).substring(0, nameLen);
	}
	@Override
	public short getChecksum() {
		return checksum;
	}
	@Override
	public int getSpace2Index() {
		return 35;
	}
	@Override
	public int getIdentAreaSize() {
		return 324;
	}
}
